==> api-notebook-react-0.2.1.tgz: package/src/component.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { monacoUrl } from './config';

export default class Notebook extends React.PureComponent {
  static propTypes = {
    notebookState: PropTypes.object,
    isFocused: PropTypes.bool,
    initialLineNumber: PropTypes.number,
    onChange: PropTypes.func,
    onRemove: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    onExecute: PropTypes.func
  };

  static defaultProps = {
    notebookState: { content: '' },
    isFocused: false,
    initialLineNumber: 0,
    onChange: () => {},
    onRemove: () => {},
    onFocus: () => {},
    onBlur: () => {},
    onExecute: () => {}
  };

  componentDidMount() {
    window.require.config({ paths: { vs: monacoUrl } });
    window.require(['vs/editor/editor.main'], () => {
      const isFocused = this.props.isFocused;
      const code = this.props.notebookState.content;
      const editorElement = document.createElement('div');

      this.notebook.appendChild(editorElement);
      this.updateHeight(editorElement, code);
      this.editor = monaco.editor.create(editorElement, {
        automaticLayout: true,
        hideCursorInOverviewRuler: true,
        minimap: {
          enabled: false,
          showSlider: false
        },
        contextmenu: false,
        scrollbar: {
          vertical: 'hidden',
          handleMouseWheel: false
        },
        value: code,
        language: 'javascript',
        lineNumbers: 'off' // this.getLineNumber
      });

      const isEmpty = this.editor.createContextKey('isEmpty', !code);

      this.editor.onDidChangeModelContent(() => {
        const newCode = this.editor.getValue();

        this.updateHeight(editorElement, newCode);
        this.editor.layout();
        isEmpty.set(!newCode);

        this.props.onChange({ ...this.props.notebookState, content: newCode });
      });

      this.editor.onDidFocusEditor(() => {
        this.props.onFocus();
      });

      this.editor.onMouseDown(() => {
        this.props.onFocus();
      });

      this.editor.onDidBlurEditor(() => {
        this.props.onBlur();
      });

      this.editor.addCommand(monaco.KeyCode.Backspace, () => {
        this.props.onRemove();
      }, 'isEmpty');

      this.editor.addCommand(monaco.KeyCode.Enter, () => {
        this.props.onExecute();
      });

      if (isFocused) {
        process.nextTick(() => this.editor.focus());
      }
    });
  }

  componentWillUnmount() {
    if (this.editor) {
      this.editor.dispose();
    }
  }

  getLineNumber = originalLineNumber => originalLineNumber + this.props.initialLineNumber

  updateHeight = (editorElement, code) => {
    editorElement.style.height = `${(code.split('\n').length + 1) * 18}px`;
    editorElement.parentNode.style.height = `${(code.split('\n').length) * 18}px`;
  }

  render() {
    const {
      notebookState: {
        exec,
        isLoading
      },
      onExecute
    } = this.props;

    return (
      <div className="notebook">
        <div className="editor-container">
          <div ref={(c) => { this.notebook = c; }} className="editor" />
          <button className={`play${isLoading ? ' loading' : ''}`} onClick={isLoading ? null : onExecute}>
            {isLoading ? 'Executing ...' : 'Play notebook'}
          </button>
        </div>
        {(exec && exec.result) ?
          <div className="success">
            <div className="block-number">{`$${exec.blockNumber}=`}</div>
            <div className="result">{stringify(exec.result)}</div>
          </div> :
          null
        }
        {(exec && exec.error) ?
          <div className="error">
            <div className="block-number">{`$${exec.blockNumber}=`}</div>
            <div className="result">{exec.error.stack}</div>
          </div> :
          null
        }
      </div>
    );
  }
}

function stringify(object) {
  try {
    return JSON.stringify(object, null, 2);
  } catch (err) {
    return object.toString();
  }
}

==> api-notebook-react-0.2.20.tgz: package/src/component.js <==
import React from 'react';
import PropTypes from 'prop-types';

export default class Notebook extends React.PureComponent {
  static propTypes = {
    notebookState: PropTypes.object,
    isFocused: PropTypes.bool,
    initialLineNumber: PropTypes.number,
    onChange: PropTypes.func,
    onRemove: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    onExecute: PropTypes.func,
    loaderPath: PropTypes.string.isRequired
  };

  static defaultProps = {
    notebookState: { content: '' },
    isFocused: false,
    initialLineNumber: 0,
    onChange: () => {},
    onRemove: () => {},
    onFocus: () => {},
    onBlur: () => {},
    onExecute: () => {}
  };

  componentDidMount() {
    const moduleRequire = window.require || window.xrequire;

    if (!moduleRequire) {
      throw new Error('Notebook loader is required');
    }

    moduleRequire.config({ paths: { vs: this.props.loaderPath } });
    moduleRequire(['vs/editor/editor.main'], () => {
      const isFocused = this.props.isFocused;
      const code = this.props.notebookState.content;
      const editorElement = document.createElement('div');

      this.notebook.appendChild(editorElement);
      this.updateHeight(editorElement, code);
      this.editor = monaco.editor.create(editorElement, {
        automaticLayout: true,
        hideCursorInOverviewRuler: true,
        minimap: {
          enabled: false,
          showSlider: false
        },
        contextmenu: false,
        scrollbar: {
          vertical: 'hidden',
          handleMouseWheel: false
        },
        value: code,
        language: 'javascript',
        lineNumbers: 'off' // this.getLineNumber
      });

      const isEmpty = this.editor.createContextKey('isEmpty', !code);

      this.editor.onDidChangeModelContent(() => {
        const newCode = this.editor.getValue();

        this.updateHeight(editorElement, newCode);
        this.editor.layout();
        isEmpty.set(!newCode);

        this.props.onChange({ ...this.props.notebookState, content: newCode });
      });

      this.editor.onDidFocusEditor(() => {
        this.props.onFocus();
      });

      this.editor.onMouseDown(() => {
        this.props.onFocus();
      });

      this.editor.onDidBlurEditor(() => {
        this.props.onBlur();
      });

      this.editor.addCommand(monaco.KeyCode.Backspace, () => {
        this.props.onRemove();
      }, 'isEmpty');

      this.editor.addCommand(monaco.KeyCode.Enter, () => {
        this.props.onExecute();
      });

      if (isFocused) {
        process.nextTick(() => this.editor.focus());
      }
    });
  }

  componentWillUnmount() {
    if (this.editor) {
      this.editor.dispose();
    }
  }

  getLineNumber = originalLineNumber => originalLineNumber + this.props.initialLineNumber

  updateHeight = (editorElement, code) => {
    editorElement.style.height = `${(code.split('\n').length + 1) * 18}px`;
    editorElement.parentNode.style.height = `${(code.split('\n').length) * 18}px`;
  }

  render() {
    const {
      notebookState: {
        exec,
        isLoading
      },
      onExecute
    } = this.props;

    return (
      <div className="notebook">
        <div className="editor-container">
          <div ref={(c) => { this.notebook = c; }} className="editor" />
          <button type="button" className={`play${isLoading ? ' loading' : ''}`} onClick={isLoading ? null : onExecute}>
            {isLoading ? null : <svg viewBox="0 0 20 20">
              <polygon points="8,6 14,10 8,14" />
              <circle cx="10" cy="10" r="9" strokeWidth="2" fill="transparent" />
            </svg>}
            {isLoading ? 'Executing ...' : 'Play'}
          </button>
        </div>
        {(exec && exec.result) ?
          <div className="success">
            <div className="block-number">{`$${exec.blockNumber}=`}</div>
            <div className="result">{stringify(exec.result)}</div>
          </div> :
          null
        }
        {(exec && exec.error) ?
          <div className="error">
            <div className="block-number">{`$${exec.blockNumber}=`}</div>
            <div className="result">{exec.error.stack}</div>
          </div> :
          null
        }
      </div>
    );
  }
}

function stringify(object) {
  try {
    return JSON.stringify(object, null, 2);
  } catch (err) {
    return object.toString();
  }
}
